<?php

namespace Fastrack\Utilities;

use GuzzleHttp\Client;
use GuzzleHttp\HandlerStack;
use GuzzleLogMiddleware\Handler\LogLevelStrategy\StatusCodeStrategy;
use GuzzleLogMiddleware\Handler\MultiRecordArrayHandler;
use GuzzleLogMiddleware\LogMiddleware;
use Psr\Log\LoggerInterface;
use Psr\Log\LogLevel;
use SilverStripe\Core\Injector\Injector;

class Http
{

	public static function buildClient(bool $log): Client
	{
		if (!$log) {
			return new Client();
		}
		$strategy = new StatusCodeStrategy(LogLevel::INFO, LogLevel::CRITICAL);
		$strategy->setLevel(404, LogLevel::WARNING);
		$logger = Injector::inst()->get(LoggerInterface::class);
		$stack = HandlerStack::create();
		$stack->push(new LogMiddleware($logger, new MultiRecordArrayHandler($strategy, 99999)));
		return new Client(['handler' => $stack]);
	}

	public static function isValidStatusCode(int $code): bool
	{
		$statusCodes = [
			100, 101,
			200, 201, 202, 203, 204, 205, 206,
			300, 301, 302, 303, 304, 305, 306, 307,
			400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417,
			500, 501, 502, 503, 504, 505
		];
		return in_array($code, $statusCodes);
	}
}
