<?php

namespace Fastrack\Utilities;

use SilverStripe\View\ArrayData;

class Link
{

	const LINK_FORMAT = '[Link name](https://link.com){:target="_blank":.class-one:id="line-one"}';
	const ATTRIBUTES = 'Attributes';
	const CLASSES = 'Classes';
	const LABEL = 'Label';
	const LINK = 'Link';

	/**
	 * Build link with label from markdown format
	 *
	 * E.g. [Link name](https://link.com){:target="_blank"}
	 *
	 * @param string|null $link
	 * @return ArrayData|null
	 */
	public static function buildLink($link, $defaultLabel='View More', $classes='')
	{
		if (!$link) {
			return null;
		}
		$structuredLink = new ArrayData([
			self::LABEL => $defaultLabel,
			self::LINK => $link,
			self::ATTRIBUTES => '',
			self::CLASSES => $classes,
		]);
		$matched = preg_match('/(\[)(.+)(])(\()(.+)(\))({.+})?/', $link, $matches);
		if ($matched) {
			$structuredLink->setField(self::LABEL, $matches[2]);
			$structuredLink->setField(self::LINK, $matches[5]);
			if (array_key_exists(7, $matches)) {
				self::getLinkAttributes($structuredLink, $matches[7]);
			}
		}
		return $structuredLink;
	}

	private static function getLinkAttributes(ArrayData $link, string $attributes)
	{
		foreach (explode(':', trim($attributes, '{}')) as $attribute) {
			if ($attribute && $attribute[0] === '.') {
				$class = str_replace('.', ' ', $attribute);
				$link->setField(self::CLASSES, $link->getField(self::CLASSES) . $class);
			} else {
				$link->setField(self::ATTRIBUTES, $link->getField(self::ATTRIBUTES) . ' ' . $attribute);
			}
		}
	}
}
