<?php


namespace Fastrack\Utilities;


use SilverStripe\Forms\HeaderField;
use SilverStripe\Forms\LiteralField;
use SilverStripe\Forms\ReadonlyField;
use SilverStripe\Forms\TextField;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\Security\Security;

class Mail extends DataObject implements PermissionProvider
{

	private static $table_name = 'mail';

	private static $db = [
		'To' => 'Varchar(255)',
		'From' => 'Varchar(255)',
		'Body' => 'Text',
	];

	private static $plural_name = 'Mail';

	private static $field_labels = [
		'Created' => 'Sent'
	];

	private static $summary_fields = [
		'From',
		'To',
		'Created',
	];

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->addFieldToTab('Root.Main', LiteralField::create('Body', $this->getBodyContentsOfEmail()));
		$fields->addFieldsToTab('Root.Main', ReadonlyField::create('Created', 'Sent', $this->Created), 'To');
		return $fields;
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_MAIL' => [
				'name' => 'Manage mail',
				'category' => 'Mail',
				'sort' => -100,
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_MAIL']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_MAIL']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_MAIL']);
	}

	public function canCreate($member = null, $context = array())
	{
		return false;
	}

	private function getBodyContentsOfEmail()
	{
		$document = new \DOMDocument();
		$contents = new \DOMDocument();
		$document->loadHTML($this->Body);
		$body = $document->getElementsByTagName('body')->item(0);
		foreach ($body->childNodes as $childNode) {
			$contents->appendChild($contents->importNode($childNode, true));
		}
		return '<div class="form-group"><label class="form__field-label">Message</label>'
			. $contents->saveHTML() . '</div>';
	}
}
