<?php


namespace Fastrack\Utilities;

use SilverStripe\Core\Config\Config;
use SilverStripe\Core\Environment;
use SilverStripe\Forms\FieldList;
use SilverStripe\ORM\DataObject;

class ModelUtilities
{

	const PRESETS = [
		'ALL_SEO_FIELDS' => [
			'MetaTitle',
			'DoNotShowSiteTitle',
			'MetaDescription',
			'ShowInSiteMap',
			'TwitterSite',
			'TwitterTitle',
			'TwitterDescription',
			'TwitterImageAltTag',
			'OpenGraphTitle',
			'OpenGraphType',
			'JavaScriptHead',
			'JavaScriptBodyTop',
			'JavaScriptBodyBottom',
			'TwitterSeo',
			'OpenGraph',
			'CustomHTML',
			'SeoTitle',
		],
		'ALL_WORKFLOW_FIELDS' => [
			'Workflow',
			'AdditionalWorkflowDefinitions',
		],
		'ALL_PROPERTY_LOGOS' => [
			'Logo',
			'PropertyLogo',
			'AlternativePropertyLogo',
		],
		'ALL_PROPERTY_EXTERNAL_REVIEWS' => [
			'ExternalReviews',
			'TripAdvisorReviewId',
			'ReviewScore',
		],
		'ALL_PROPERTY_PMS_DETAILS' => [
			'PMSDetails',
			'PmsProvider',
			'PmsProvider',
			'PmsPropertyId',
			'PmsSubPropertyId',
			'PmsBookingLink',
		],
		'EXTRA_CONTACT_FIELDS' => [
			'ContactFormEmail',
			'AfterHoursPhone',
			'InternationalPhone',
			'FreeCallPhone',
			'MobilePhone',
			'Fax',
			'Facebook',
			'Youtube',
			'Instagram',
			'Twitter',
			'LinkedIn',
		],
		'EXTRA_LOCATION_FIELDS' => [
			'RegionID',
			'SubRegionID',
			'Country',
			'Directions',
			'MapUrl',
			'MapPin',
		],
	];

	public static function hideHasOneFields(DataObject $dataObject, FieldList $fieldList): FieldList
	{
		foreach ($dataObject->hasOne() as $key => $value) {
			$fieldList->removeByName($key . 'ID');
		}
		return $fieldList;
	}

	/**
	 * @deprecated
	 *
	 * @param DataObject $dataObject
	 * @param FieldList $fieldList
	 * @return FieldList
	 */
	public static function hideFields(DataObject $dataObject, FieldList $fieldList): FieldList
	{
		$class = substr(strrchr($dataObject->getClassName(), '\\'), 1);
		$setting = Environment::getEnv(join('_', ['HIDDEN_FIELDS', $class]));
		if ($setting) {
			$fieldKeys = explode(',', $setting);
			foreach ($fieldKeys as $fieldKey) {
				self::hideField($fieldList, $fieldKey);
			}
		}
		return $fieldList;
	}

	public static function hideConfigFields($class, FieldList $fields)
	{
		$fieldKeys = Config::inst()->get($class, 'hidden_fields');
		if (!$fieldKeys) return;
		foreach ($fieldKeys as $fieldKey) {
			if (array_key_exists($fieldKey, self::PRESETS)) {
				foreach (self::PRESETS[$fieldKey] as $fieldName) {
					self::hideField($fields, $fieldName);
				}
			} else {
				self::hideField($fields, $fieldKey);
			}
		}
	}

	private static function hideField(FieldList $fieldList, string $fieldKey)
	{
		if (str_contains($fieldKey, '.')) {
			$components = explode('.', $fieldKey);
			$field = [array_pop($components)];
			$fieldList->removeFieldsFromTab(implode('.', $components), $field);
		} else {
			$fieldList->removeByName($fieldKey);
		}
	}

}
