<?php

namespace Fastrack\Utilities\ServicesApi;

use DateTime;

class QuoteResponse implements Response
{
	private array $data;

	/** @var QuoteCharge[]  */
	private array $nightlyRates;

	private RateDetail $rate;

	public function __construct(array $data)
	{
		$this->data = $data;

		$this->rate = new RateDetail();
		$this->rate->setId($data['rate']['id']);
		$this->rate->setName($data['rate']['name']);
		$this->rate->setDescription($data['rate']['description']);

		$this->nightlyRates = [];
		foreach ($data['nightlyRates'] as $nightlyRate) {
			$charge = new QuoteCharge();
			$charge->setId($nightlyRate['id']);
			$charge->setDate(DateTime::createFromFormat('Y-m-d', $nightlyRate['date']));
			$charge->setPrice(intval($nightlyRate['price']));
			$this->nightlyRates[] = $charge;
		}
	}

	public function  getRoomId(): int
	{
		return $this->data['roomId'];
	}

	public function  getPropertyId(): int
	{
		return $this->data['propertyId'];
	}

	public function  getAdults(): int
	{
		return $this->data['adults'];
	}

	public function  getChildren(): int
	{
		return $this->data['children'];
	}

	public function  getInfants(): int
	{
		return $this->data['infants'];
	}

	public function  isAvailable(): bool
	{
		return (bool)$this->data['available'];
	}

	public function  getStatus(): string
	{
		return $this->data['status'];
	}

	public function  getMinimumLengthOfStay(): int
	{
		return $this->data['minimumLengthOfStay'];
	}

	public function  getMaximumLengthOfStay(): int
	{
		return $this->data['maximumLengthOfStay'];
	}

	public function  getMaximumOccupancy(): int
	{
		return $this->data['maximumOccupancy'];
	}

	public function  getCurrency(): string
	{
		return $this->data['currency'];
	}

	public function  getDiscountId(): int
	{
		return $this->data['discountId'];
	}

	public function  getTotalDiscount(): int
	{
		return $this->data['totalDiscount'];
	}

	public function  getTotalPrice(): int
	{
		return $this->data['totalPrice'];
	}

	public function  getTotalTax(): int
	{
		return $this->data['totalTax'];
	}

	public function  getTotalTotal(): int
	{
		return $this->data['totalTotal'];
	}

	public function  getValidPromoCode(): bool
	{
		return $this->data['validPromoCode'];
	}

	public function  getDeposit(): int
	{
		return $this->data['deposit'];
	}

	public function getArrive(): DateTime
	{
		return DateTime::createFromFormat('Y-m-d', $this->data['arrival']);
	}

	public function getDepart(): DateTime
	{
		return DateTime::createFromFormat('Y-m-d', $this->data['departure']);
	}

	public function getRate(): RateDetail
	{
		return $this->rate;
	}

	/**
	 * @return QuoteCharge[]
	 */
	public function getNightlyRates(): array
	{
		return $this->nightlyRates;
	}

	public function getData(): array
	{
		return $this->data;
	}

}
